using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace DemoAddin
{
	/// <summary>
	/// Content of the tool window.
	/// </summary>
	public partial class DemoToolWindowControl : UserControl
	{
		private TreeNode BuildTreeNode( HierarchyItem item )
		{
			TreeNode objTreeNode = new TreeNode( item.Text );
			foreach (HierarchyItem objChild in item.Children)
				objTreeNode.Nodes.Add( BuildTreeNode( objChild ) );

			return objTreeNode;
		}

		private void BuildTree( UpdateEventArgs objArgs )
		{
			c_tvwCodeElements.Nodes.Clear();
			c_tvwCodeElements.Nodes.Add(BuildTreeNode(objArgs.Root));
		}

		private void c_btnUpdate_Click( object sender, EventArgs e )
		{
			RebuildTree();
		}

		/// <summary>
		/// Raises the <see cref="E:BuildingTree"/> event.
		/// </summary>
		/// <param name="e">The <see cref="DemoAddin.UpdateEventArgs"/> instance containing the event data.</param>
		protected virtual void OnBuildingTree( UpdateEventArgs e )
		{
			EventHandler<UpdateEventArgs> handler = this.BuildingTree;
			if (handler != null) handler( this, e );
		}

		//===================================================
		// Public
		//===================================================

		/// <summary>
		/// Occurs when the tree is about to be rebuilt.
		/// </summary>
		public event EventHandler<UpdateEventArgs> BuildingTree;

		/// <summary>
		/// Rebuilds the tree.
		/// </summary>
		public void RebuildTree()
		{
			UpdateEventArgs objArgs = new UpdateEventArgs();
			OnBuildingTree( objArgs );
			BuildTree( objArgs );
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="DemoToolWindowControl"/> class.
		/// </summary>
		public DemoToolWindowControl()
		{
			InitializeComponent();
		}
	}
}
